Call

Struct Call 

pub struct Call { /* private fields */ }
Represents an ongoing (as been answered) call.

Implementations

Source

impl Call

pub async fn block_for_finished(&mut self)

Blocks until the call has finished (hang up and terminated the worker thread)

pub async fn block_for_output_empty(&mut self)

Blocks until the output buffer is empty

This is typically useful when sending already recorded sound, and you want to make sure the playback is finished before proceeding.

pub fn send_audio(&self, audio: Vec<f32>) -> Result<()>

Adds the given samples to the output audio buffer.

Arguments
  • audio: Interleaved stereo f32 samples @ 48000Hz.
Errors

Errors when failing to send the audio to the call. Most likely because the call has already ended.

pub fn hangup(&self) -> Result<()>

Tries to hang up the call. Might fail if the call is already over.

pub async fn recv(&mut self) -> Option<CallControl>

Receive the next control message from the call. Blocking until a message arrives.

pub async fn recv_media(&mut self) -> Option<Media>

Receive the next media message from the call. Blocking until a message arrives.

pub async fn recv_either( &mut self, ) -> Either<Option<CallControl>, Option<Media>>

Receive either the next control message or the next media message.

pub fn get_remote_uri(&self) -> &String

Returns the remote URI

pub fn is_finished(&self) -> bool

Returns the state of the underlying worker

true if the underlying worker as finished.